# Arithmetic

Timestreams support a variety of arithmetic operations.

```{note}
Note: In addition to the chainable methods, standard operators are implemented where appropriate.
For instance, `a.add(b)` may be written as `a + b`.
See the notes on the specific functions for more information.
```

## Arithmetic Methods

```{eval-rst}
.. currentmodule:: kaskada

.. autosummary::
   :toctree: ../apidocs/

    Timestream.add
    Timestream.ceil
    Timestream.clamp
    Timestream.div
    Timestream.exp
    Timestream.floor
    Timestream.greatest
    Timestream.least
    Timestream.mul
    Timestream.neg
    Timestream.powf
    Timestream.round
    Timestream.sqrt
    Timestream.sub
```